@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: f1c33be52278123a98a86c99b287fba92d040bdf $
 */
 
 /*
@@ -41,4 +40,7 @@
 /* Define if AVCodecContext contains the field frame_rate. */
 #undef HAVE_AVCODECCONTEXT_FRAME_RATE
 
+/* Define if AVCodec contains the field encode2. */
+#undef HAVE_AVCODEC_ENCODE2
+
 #endif
