@@ -118,8 +118,24 @@ PMOD_EXPORT struct object *low_clone(struct program *p)
 {
   struct object *o;
 
-  if(!(p->flags & PROGRAM_PASS_1_DONE))
-    Pike_error("Attempting to clone an unfinished program\n");
+  if(!(p->flags & PROGRAM_PASS_1_DONE)) {
+    /* It might be compiling in a different thread.
+     * Wait for the compiler to finish.
+     * Note that this does not block if we are the compiler thread.
+     */
+    lock_pike_compiler();
+    /* We now have the compiler lock.
+     * Three posibilities:
+     *  * The compiler was busy compiling the program in
+     *    a different thread and has now finished.
+     *  * We are the thread that is compiling the program.
+     *  * The program is a remnant from a failed compilation.
+     */
+    unlock_pike_compiler();
+    if(!(p->flags & PROGRAM_PASS_1_DONE)) {
+      Pike_error("Attempting to clone an unfinished program\n");
+    }
+  }
 
 #ifdef PROFILING
   p->num_clones++;
@@ -344,12 +360,34 @@ PMOD_EXPORT struct object *debug_clone_object(struct program *p, int args)
 {
   ONERROR tmp;
   struct object *o;
+
+  /* NB: The following test is somewhat redundant, since it is
+   *     also performed by low_clone() below. The problem is
+   *     that the PROGRAM_NEEDS_PARENT check inbetween needs
+   *     this check to have been performed before.
+   */
+  if(!(p->flags & PROGRAM_PASS_1_DONE)) {
+    /* It might be compiling in a different thread.
+     * Wait for the compiler to finish.
+     * Note that this does not block if we are the compiler thread.
+     */
+    lock_pike_compiler();
+    /* We now have the compiler lock.
+     * Three posibilities:
+     *  * The compiler was busy compiling the program in
+     *    a different thread and has now finished.
+     *  * We are the thread that is compiling the program.
+     *  * The program is a remnant from a failed compilation.
+     */
+    unlock_pike_compiler();
+    if(!(p->flags & PROGRAM_PASS_1_DONE)) {
+      Pike_error("Attempting to clone an unfinished program\n");
+    }
+  }
+
   if(p->flags & PROGRAM_NEEDS_PARENT)
     Pike_error("Parent lost, cannot clone program.\n");
 
-  if(!(p->flags & PROGRAM_PASS_1_DONE))
-    Pike_error("Attempting to clone an unfinished program\n");
-
   o=low_clone(p);
   if (!args) {
     push_object(o);
@@ -400,9 +438,6 @@ PMOD_EXPORT struct object *parent_clone_object(struct program *p,
     debug_malloc_touch(o);
   }
 
-  if(!(p->flags & PROGRAM_PASS_1_DONE))
-    Pike_error("Attempting to clone an unfinished program\n");
-
   if(p->flags & PROGRAM_USES_PARENT)
   {
     add_ref( PARENT_INFO(o)->parent=parent );
@@ -1305,9 +1340,17 @@ PMOD_EXPORT int low_object_index_no_free(struct svalue *to,
       if (i->func.const_info.offset >= 0) {
 	struct svalue *s;
 	s=& PROG_FROM_INT(p,f)->constants[i->func.const_info.offset].sval;
+	/* NB: If the program isn't finished, we can't rely on
+	 *     PROGRAM_USES_PARENT being set, so use the safe
+	 *     option of always using a function pointer in
+	 *     that case.
+	 *     Fixes [bug 7664].
+	 */
 	if(TYPEOF(*s) == T_PROGRAM &&
-	   (s->u.program->flags & PROGRAM_USES_PARENT))
+	   ((s->u.program->flags & (PROGRAM_USES_PARENT|PROGRAM_FINISHED)) !=
+	    PROGRAM_FINISHED))
 	{
+	  /* Don't lose the parent as the program needs it. */
 	  SET_SVAL(*to, T_FUNCTION, DO_NOT_WARN(f), object, o);
 	  add_ref(o);
 	}else{
