@@ -1,6 +1,4 @@
 /*
- * $Id: 23a19d69c425ff6cfd7b18a2822ba913d9c9a9d1 $
- *
  * Pike embedding API.
  *
  * Henrik Grubbstrm 2004-12-27
@@ -39,12 +37,8 @@
 #include "opcodes.h"
 #include "pike_memory.h"
 #include "pike_cpulib.h"
-
 #include "pike_embed.h"
-
-#ifdef AUTO_BIGNUM
 #include "bignum.h"
-#endif
 
 #if defined(__linux__) && defined(HAVE_DLOPEN) && defined(HAVE_DLFCN_H)
 #include <dlfcn.h>
@@ -78,8 +72,6 @@
 int try_use_mmx;
 #endif
 
-#undef ATTRIBUTE
-#define ATTRIBUTE(X)
 
 /* Define this to trace the execution of main(). */
 /* #define TRACE_MAIN */
@@ -131,27 +123,19 @@ void init_pike(char **argv, const char *file)
   init_rusage();
 
   /* Attempt to make sure stderr is unbuffered. */
-#ifdef HAVE_SETVBUF
   setvbuf(stderr, NULL, _IONBF, 0);
-#else /* !HAVE_SETVBUF */
-#ifdef HAVE_SETBUF
-  setbuf(stderr, NULL);
-#endif /* HAVE_SETBUF */
-#endif /* HAVE_SETVBUF */
 
   TRACE((stderr, "Init CPU lib...\n"));
-  
   init_pike_cpulib();
 
 #ifdef TRY_USE_MMX
   TRACE((stderr, "Init MMX...\n"));
-  
   try_use_mmx=mmx_ok();
 #endif
+
 #ifdef OWN_GETHRTIME
 /* initialize our own gethrtime conversion /Mirar */
   TRACE((stderr, "Init gethrtime...\n"));
-  
   own_gethrtime_init();
 #endif
 
@@ -159,30 +143,10 @@ void init_pike(char **argv, const char *file)
   master_file = file;
 
   TRACE((stderr, "Main init...\n"));
-  
   fd_init();
   {
-    extern void init_mapping_blocks(void);
-    extern void init_callable_blocks(void);
-    extern void init_gc_rec_frame_blocks(void);
-    extern void init_ba_mixed_frame_blocks(void);
-    extern void init_pike_frame_blocks(void);
     extern void init_node_s_blocks(void);
-    extern void init_object_blocks(void);
-    extern void init_callback_blocks(void);
-
-    init_mapping_blocks();
-    init_callable_blocks();
-    init_gc_rec_frame_blocks();
-    init_ba_mixed_frame_blocks();
-    init_catch_context_blocks();
-    init_pike_frame_blocks();
     init_node_s_blocks();
-    init_object_blocks();
-#if !defined(DEBUG_MALLOC) || !defined(_REENTRANT)
-    /* This has already been done by initialize_dmalloc(). */
-    init_callback_blocks();
-#endif /* !DEBUG_MALLOC */
     init_multiset();
     init_builtin_constants();
   }
@@ -191,7 +155,6 @@ void init_pike(char **argv, const char *file)
   tzset();
 #endif /* HAVE_TZSET */
 
-#ifdef HAVE_SETLOCALE
 #ifdef LC_NUMERIC
   setlocale(LC_NUMERIC, "C");
 #endif
@@ -207,7 +170,6 @@ void init_pike(char **argv, const char *file)
 #ifdef LC_MESSAGES
   setlocale(LC_MESSAGES, "");
 #endif
-#endif
 }
 
 static void (*pike_exit_cb)(int);
@@ -220,7 +182,7 @@ void init_pike_runtime(void (*exit_cb)(int))
   pike_exit_cb = exit_cb;
 
   TRACE((stderr, "Init C stack...\n"));
-  
+
   Pike_interpreter.stack_top = (char *)&exit_cb;
 
   /* Adjust for anything already pushed on the stack.
@@ -339,63 +301,31 @@ void init_pike_runtime(void (*exit_cb)(int))
 #endif /* STACK_DEBUG */
 #endif /* HAVE_GETRLIMIT && RLIMIT_STACK */
 
-#if 0
-#if !defined(RLIMIT_NOFILE) && defined(RLIMIT_OFILE)
-#define RLIMIT_NOFILE RLIMIT_OFILE
-#endif
-
-#if defined(HAVE_SETRLIMIT) && defined(RLIMIT_NOFILE)
-  {
-    struct rlimit lim;
-    long tmp;
-    if(!getrlimit(RLIMIT_NOFILE, &lim))
-    {
-#ifdef RLIM_INFINITY
-      if(lim.rlim_max == RLIM_INFINITY)
-	lim.rlim_max=MAX_OPEN_FILEDESCRIPTORS;
-#endif
-      tmp=MINIMUM(lim.rlim_max, MAX_OPEN_FILEDESCRIPTORS);
-      lim.rlim_cur=tmp;
-      setrlimit(RLIMIT_NOFILE, &lim);
-    }
-  }
-#endif
-#endif
-  
   TRACE((stderr, "Init time...\n"));
-  
-  GETTIMEOFDAY(&current_time);
+  UPDATE_CURRENT_TIME();
 
   TRACE((stderr, "Init threads...\n"));
-
   low_th_init();
 
   TRACE((stderr, "Init strings...\n"));
-  
   init_shared_string_table();
 
   TRACE((stderr, "Init interpreter...\n"));
-
   init_interpreter();
 
   TRACE((stderr, "Init types...\n"));
-
   init_types();
 
   TRACE((stderr, "Init opcodes...\n"));
-
   init_opcodes();
 
   TRACE((stderr, "Init destruct...\n"));
-
   low_init_object();
 
   TRACE((stderr, "Init programs...\n"));
-
   init_program();
 
   TRACE((stderr, "Init objects...\n"));
-
   init_object();
 
   if(SETJMP(back))
@@ -414,7 +344,6 @@ void init_pike_runtime(void (*exit_cb)(int))
     back.severity=THROW_EXIT;
 
     TRACE((stderr, "Init modules...\n"));
-
     init_modules();
 
 #ifdef TEST_MULTISET
@@ -432,7 +361,7 @@ void init_pike_runtime(void (*exit_cb)(int))
 /* FIXME: Thread specific limit? */
 static unsigned long instructions_left = 0;
 
-static void time_to_exit(struct callback *cb,void *tmp,void *ignored)
+static void time_to_exit(struct callback *UNUSED(cb), void *UNUSED(tmp), void *UNUSED(ignored))
 {
   if(!(instructions_left--))
   {
@@ -483,7 +412,7 @@ void gdb_break_on_pike_stack_record(long stack_size)
 static unsigned int samples[8200];
 long record;
 
-static void sample_stack(struct callback *cb,void *tmp,void *ignored)
+static void sample_stack(struct callback *cb,void *UNUSED(tmp),void *UNUSED(ignored))
 {
   long stack_size=( ((char *)&cb) - Pike_interpreter.stack_bottom) * STACK_DIRECTION;
   stack_size>>=10;
@@ -551,16 +480,16 @@ void pike_do_exit(int num)
 #endif
 
 #ifdef PIKE_DEBUG
-  if (svalue_int_zero.type != T_INT ||
-      svalue_int_zero.subtype != NUMBER_NUMBER ||
+  if (TYPEOF(svalue_int_zero) != T_INT ||
+      SUBTYPEOF(svalue_int_zero) != NUMBER_NUMBER ||
       svalue_int_zero.u.integer != 0)
     Pike_fatal ("svalue_int_zero has been changed.\n");
-  if (svalue_undefined.type != T_INT ||
-      svalue_undefined.subtype != NUMBER_UNDEFINED ||
+  if (TYPEOF(svalue_undefined) != T_INT ||
+      SUBTYPEOF(svalue_undefined) != NUMBER_UNDEFINED ||
       svalue_undefined.u.integer != 0)
     Pike_fatal ("svalue_undefined has been changed.\n");
-  if (svalue_int_one.type != T_INT ||
-      svalue_int_one.subtype != NUMBER_NUMBER ||
+  if (TYPEOF(svalue_int_one) != T_INT ||
+      SUBTYPEOF(svalue_int_one) != NUMBER_NUMBER ||
       svalue_int_one.u.integer != 1)
     Pike_fatal ("svalue_int_one has been changed.\n");
 #endif
@@ -578,8 +507,7 @@ void pike_push_argv(int argc, char **argv)
   a=allocate_array_no_init(argc,0);
   for(num=0;num<argc;num++)
   {
-    ITEM(a)[num].u.string=make_shared_string(argv[num]);
-    ITEM(a)[num].type=T_STRING;
+    SET_SVAL(ITEM(a)[num], T_STRING, 0, string, make_shared_string(argv[num]));
   }
   a->type_field = BIT_STRING;
   push_array(a);
@@ -599,7 +527,7 @@ static SAVEDS LONG scan_amigaos_environment_func(struct Hook *REG(a0,hook),
   if(msg->sv_GDir[0] == '\0' ||
      !strcmp(msg->sv_GDir, "ENV:")) {
     push_text(msg->sv_Name);
-    push_constant_text("=");
+    push_text("=");
     push_string(make_shared_binary_string(msg->sv_Var, msg->sv_VarLen));
     f_add(3);
   }
@@ -640,8 +568,8 @@ void pike_push_env(void)
   a=allocate_array_no_init(num,0);
   for(num=0;environ[num];num++)
   {
-    ITEM(a)[num].u.string=make_shared_string(environ[num]);
-    ITEM(a)[num].type=T_STRING;
+    SET_SVAL(ITEM(a)[num], T_STRING, 0,
+	     string, make_shared_string(environ[num]));
   }
   a->type_field = BIT_STRING;
   push_array(a);
