@@ -319,7 +319,11 @@ static ptrdiff_t low_cpp(struct cpp *this,
                         string_builder_putchar(&tmp, '\\');
                         string_builder_putchar(&tmp, INDEX_PCHARP(a,e));
                         if (INDEX_PCHARP(a,e) == '"') {
-                          for (e++; (e < l) && (INDEX_PCHARP(a,e) != '"'); e++) {
+                          for (e++; e < l; e++) {
+                            if (INDEX_PCHARP(a,e) == '"') {
+                                e++;
+                                break;
+                            }
                             string_builder_putchar(&tmp, INDEX_PCHARP(a,e));
                             if (INDEX_PCHARP(a,e) == '\\') {
                               string_builder_putchar(&tmp, '\\');
@@ -331,7 +335,6 @@ static ptrdiff_t low_cpp(struct cpp *this,
                           }
                           string_builder_putchar(&tmp, '\\');
                           string_builder_putchar(&tmp, '"');
-                          e++;
                         }
                       } else {
                         /* White space. */
