@@ -1,9 +1,11 @@
-/* File generated on Thu May  1 02:28:46 EDT 2014
+/* File generated on Thu Dec 31 21:22:56 CET 2015
 by getwhitespace <UnicodeData.txt */
 
+#define SPACECASE8							\
+       case ' ':case '\t':case '\r':case '\n':case '\v':case '\f':	\
+       case 0x85:case 0xa0:
 #define SPACECASE16	SPACECASE8 \
 case 0x1680:\
-case 0x180e:\
 case 0x2000:\
 case 0x2001:\
 case 0x2002:\
